parse_boxes

Function parse_boxes 

pub fn parse_boxes<R: Read + Seek>(
    r: &mut R,
    start: u64,
    end: u64,
) -> Result<Vec<BoxRef>>
Parse all boxes in the byte range [start, end).

This is the entry point for parsing a whole file (start = 0, end = file length) or any sub-range. The first malformed box aborts the parse with an error; see parse_boxes_tolerant for the recovering variant.